#include <ESP8266WiFi.h>
#include <ESP8266mDNS.h>
#include <WiFiUdp.h>
#include "esp8266_hw.h"
#include "wifiCredentials.h"
#include "networkSettings.h"

extern "C" {
#include "user_interface.h"
}

int status = WL_IDLE_STATUS;

byte packetBuffer[512]; //buffer to hold incoming and outgoing packets

WiFiUDP Udp;

void vSendUdp(String sz, unsigned int uiLocalPort) {
  Udp.beginPacket(REMOTE_IP, uiLocalPort);
  Udp.print(sz);
  Udp.endPacket();
  Serial.print("Tramès: ");
  Serial.print(sz);
  Serial.print(" pel port ");
  Serial.println(uiLocalPort);
}

//  WiFi{

void vDelayESP(unsigned long ulMilliseconds) {
  unsigned long ulPreviousMillis = millis();

  do {
    yield();
  } while (millis() - ulPreviousMillis <= ulMilliseconds);
}

void vConnectToWiFi(const char* szSsid, const char* szPwd) {
  char ssid[MAX_STRING_SIZE],  pwd[MAX_STRING_SIZE];

  Serial.println("Connecting to WiFi network: " + String(szSsid) + ", pwd: " + String(szPwd));

  WiFi.begin(szSsid, szPwd);

  Serial.println("Waiting for WIFI connection...");
  while (WiFi.status() != WL_CONNECTED /*&& i++ < 20*/) {
    Serial.print(".");
    vDelayESP(500);
  }
  Serial.println();
}

boolean bIsListed(String szSSID, int *pNwO) {
  for (int i = 0; i < N_WIFIS ; i++) {
    if (String(stWiFi[i].szSSID) == szSSID) {
      *pNwO = i;
      return true;
    }
  }
  return false;
}

boolean bTryWifiConnection() {
  int n = WiFi.scanNetworks(), nWhichOne;

  //Serial.print("*");
  if (n == 0) {
    Serial.println("\nNo networks found");
    vDelayESP(1000);
  } else {
    for (int i = 0; i < n; ++i) {
      if (bIsListed(WiFi.SSID(i), &nWhichOne)) {
        vConnectToWiFi(stWiFi[nWhichOne].szSSID, stWiFi[nWhichOne].szPWD);
        return true;
      }
    }
  }
  return false;
}

void setup_wifi() {
  do {
    WiFi.mode(WIFI_STA);
    WiFi.disconnect();
    vDelayESP(100);
  } while (!bTryWifiConnection());
  IPAddress ip = WiFi.localIP();
  Serial.print("Connected to wifi at "); Serial.println(ip);
}

// }WiFi

void setup() {
  Serial.begin(115200);

  setup_wifi();
}

void vBotoPremut(int nQuin){
  char szVector[33];
  Serial.print("Premut el botó ");
  Serial.println(nQuin);
  sprintf(szVector,"Premut el botó %d",nQuin);
  vSendUdp(szVector , udpPortTx);
}

void loop() {
  static bool bLastButtonState0 = HIGH, bLastButtonState4 = HIGH;
  bool bButtonState0 = digitalRead(0);
  bool bButtonState4 = digitalRead(4);

  if (bButtonState0 != bLastButtonState0) {
    if (bButtonState0 == LOW) {
      vBotoPremut(0);
    }
  }
  bLastButtonState0 = bButtonState0;
  if (bButtonState4 != bLastButtonState4) {
    if (bButtonState4 == LOW) {
      vBotoPremut(4);
    }
  }
  bLastButtonState4 = bButtonState4;
}


